#!/bin/bash
################################################################################
# Copyright (c) 2021 Jersey Jack Pinball
################################################################################
# process command line options
################################################################################
# put a : in the beginning of the option string to suppress getopts error
# message. follow an option with a : to make getopts require an argument.
# it can be accessed in the variable OPTARG.
while getopts ":eu?" opt; do
  case $opt in
    e ) exclude_pics='true' ;;
    u ) put_on_usb_stick='true' ;;
   \? ) show_usage
        exit 1 ;;
  esac
done
# this shift puts the remaining command arguments into variables $1, 2$, 3$...
shift $(($OPTIND - 1))

################################################################################
# main code
################################################################################
ts=$(date +"%Y%m%d-%H%M%S")
usb_folder='/mnt/usb'
tmp_root='/tmp'
logdump_dirname='logdump'
tmp_folder="${tmp_root}/${logdump_dirname}"

rm -rf "$tmp_folder"
mkdir -p "${tmp_folder}/vf"

export DISPLAY=:0
xrandr > "$tmp_folder"/xrandroutput.txt
cp /var/log/kern.log* "$tmp_folder"
cp /var/log/syslog* "$tmp_folder"
cp /var/log/Xorg* "$tmp_folder"
cp /var/log/dmesg* "$tmp_folder"
cp /var/log/boot.log "$tmp_folder"
cp -r /jjpe/temp/varlogs "$tmp_folder"
cp /jjpe/temp/*.log* "$tmp_folder"
cp /jjpe/temp/*progress "$tmp_folder"
cp /jjpe/temp/curl* "$tmp_folder"
cp /tmp/hwinfo "$tmp_folder"
cp -r /tmp/pinballstats "$tmp_folder"
cp /jjpe/gen1/setenv.sh "$tmp_folder"
cp /jjpe/gen1/setup_displays.sh "$tmp_folder"
cp /etc/timezone "$tmp_folder"
mount > "$tmp_folder"/mount_output.txt
df -h > "$tmp_folder"/df_output.txt
lsusb > "$tmp_folder"/lsusb_output.txt
lsusb -vv > "$tmp_folder"/lsusb_output_verbose.txt
journalctl -o short-precise > "$tmp_folder"/systemdlog.txt
amixer > "$tmp_folder"/amixeroutput.txt
pactl list > "$tmp_folder"/pactl_list_output.txt
pactl list cards > "$tmp_folder"/pactl_card_output.txt
cp -r /jjpe/perm/vf/* "$tmp_folder"/vf

if [ $exclude_pics ]; then
  rm -rf "$tmp_folder"/vf/misc/photos
fi

cd "$tmp_root"
if [ $put_on_usb_stick ]; then
  zip -r "${usb_folder}/logdump-${ts}.zip" "$logdump_dirname"/*
  umount /mnt/usb
else
  rm -rf /jjpe/temp/sndlogs
  mkdir -p /jjpe/temp/sndlogs
  echo "$ts" > /jjpe/temp/t
  zip -r "/jjpe/temp/sndlogs/logdump-${ts}.zip" "$logdump_dirname"/*
fi
