#!/usr/bin/perl
# ------------------------------------------------------------------------------
# -- Copyright (c) 2021 Jersey Jack Pinball ------------------------------------
# ------------------------------------------------------------------------------
use utf8;
use strict;
use warnings;
use Log::Log4perl;

# ------------------------------------------------------------------------------
# -- libraries -----------------------------------------------------------------
# ------------------------------------------------------------------------------
require '/jjpe/gen1/scripts/net/jjp.pm';

# ------------------------------------------------------------------------------
# -- logging -------------------------------------------------------------------
# ------------------------------------------------------------------------------
my $conf = q(
    log4perl.category.jjp.net          = INFO, Logfile
    log4perl.appender.Logfile          = Log::Log4perl::Appender::File
    log4perl.appender.Logfile.filename = /jjpe/temp/net.log
    log4perl.appender.Logfile.layout   = Log::Log4perl::Layout::PatternLayout
    log4perl.appender.Logfile.layout.ConversionPattern = \\
        [%d] %p - script: %F - line number: %L - message: %m%n
);

Log::Log4perl::init(\$conf);
my $logger = Log::Log4perl->get_logger('jjp::net');

# ------------------------------------------------------------------------------
# -- main ----------------------------------------------------------------------
# ------------------------------------------------------------------------------
my ($game_abbrev, $update_filename, $size, $mirror) = @ARGV;
if (not defined $game_abbrev or not defined $update_filename
    or not defined $size or not defined $mirror) {
    $logger->error('missing args');
    exit;
}

my $filename = "/jjpe/temp/$update_filename";
my $existing_size = -s $filename;
if (defined $existing_size) {
    if ($existing_size >= $size) {
        $logger->info("$update_filename already exists at size: $size");
        print 'success';
        exit;
    }
}

my $default_options = "-C - --connect-timeout 3 --speed-time 10 "
    ."--speed-limit 1024";
my $curl_update_options = jjp::get_curl_update_options();
my $options = "-o $filename $default_options $curl_update_options";
my $server = jjp::get_us_update_server();
my $dl_url = "$server/$game_abbrev/$update_filename";
if ($mirror eq 'eu') {
    $server = jjp::get_eu_update_server();
    $dl_url = "$server/$game_abbrev/$update_filename";
}

chdir '/jjpe/temp';
my $ret_code = 1;
$logger->info("attempting to download file $update_filename");
for (1 .. 999999) {
    system "curl $options $dl_url 2> cprogress";
    $ret_code = ($? >> 8);
    system "echo $ret_code > curlretcode";
    system "sync";
    if (not $ret_code) {
        last;
    } else {
        sleep 1;
    }
}

if ($ret_code == 0 and -e $filename) {
    $logger->info("downloaded file $update_filename");
    print 'success';
} else {
    $logger->error("failed to download $update_filename");
    print 'failure';
}
