#!/usr/bin/perl
# ------------------------------------------------------------------------------
# -- Copyright (c) 2021 Jersey Jack Pinball ------------------------------------
# ------------------------------------------------------------------------------
use utf8;
use strict;
use warnings;
use Log::Log4perl;

# ------------------------------------------------------------------------------
# -- logging -------------------------------------------------------------------
# ------------------------------------------------------------------------------
my $conf = q(
    log4perl.category.jjp.net          = INFO, Logfile
    log4perl.appender.Logfile          = Log::Log4perl::Appender::File
    log4perl.appender.Logfile.filename = /jjpe/temp/net.log
    log4perl.appender.Logfile.layout   = Log::Log4perl::Layout::PatternLayout
    log4perl.appender.Logfile.layout.ConversionPattern = \\
        [%d] %p - script: %F - line number: %L - message: %m%n
);

Log::Log4perl::init(\$conf);
my $logger = Log::Log4perl->get_logger('jjp::net');

# ------------------------------------------------------------------------------
# -- globals -------------------------------------------------------------------
# ------------------------------------------------------------------------------
my $filename = '/jjpe/temp/cprogress';
my @lines = ();

# ------------------------------------------------------------------------------
# -- functions -----------------------------------------------------------------
# ------------------------------------------------------------------------------
sub convert_suffixes {
    my ($field) = @_;
    if ($$field =~ /\d+/) {
        $$field .= 'b';
    } else {
        $$field =~ s/k/kb/g;
        $$field =~ s/M/Mb/g;
        $$field =~ s/G/Gb/g;
        $$field =~ s/T/Tb/g;
        $$field =~ s/P/Pb/g;
    }
}

# ------------------------------------------------------------------------------
# -- main ----------------------------------------------------------------------
# ------------------------------------------------------------------------------
if (-e $filename) {
    if (open PROGRESS, '<', $filename) {
        while (<PROGRESS>) {
            chomp;
            s/
/\n/g;
            my @split_lines = split '\n';
            push @lines, @split_lines;
        }
    
        close PROGRESS;
    } else {
        $logger->error('could not open file');
        print "--:--:--:--:--:--:--:";
        exit;
    }
}

my $num_of_lines = @lines;
if ($num_of_lines > 2 and $lines[-1]) {
    if ($lines[-1] =~ /Killed/) {
        print "--:--:--:--:--:--:--:";
    } elsif ($lines[-1] =~ /Operation/) {
        print "--:--:--:--:--:--:--:";
    } elsif ($lines[-1] =~ /Resolving/) {
        print "--:--:--:--:--:--:--:";
    } else {
        my @fields = split /\s+/, $lines[-1];
        my $num_of_fields = @fields;
        if ($num_of_fields == 13) {
            convert_suffixes \$fields[2];
            convert_suffixes \$fields[4];
            convert_suffixes \$fields[7];
            convert_suffixes \$fields[12];
            $fields[9] =~ s/:/-/g;
            $fields[10] =~ s/:/-/g;
            $fields[11] =~ s/:/-/g;
            print "$fields[2]:$fields[4]:$fields[7]:$fields[9]:$fields[10]:"
                ."$fields[11]:$fields[12]:";
        } else { 
            print "--:--:--:--:--:--:--:";
        }
	}
} else { 
    print "--:--:--:--:--:--:--:";
}
