#!/usr/bin/perl
# ------------------------------------------------------------------------------
# -- Copyright (c) 2021 Jersey Jack Pinball ------------------------------------
# ------------------------------------------------------------------------------
use utf8;
use strict;
use warnings;
use Log::Log4perl;

# ------------------------------------------------------------------------------
# -- logging -------------------------------------------------------------------
# ------------------------------------------------------------------------------
my $conf = q(
    log4perl.category.jjp.net          = INFO, Logfile
    log4perl.appender.Logfile          = Log::Log4perl::Appender::File
    log4perl.appender.Logfile.filename = /jjpe/temp/net.log
    log4perl.appender.Logfile.layout   = Log::Log4perl::Layout::PatternLayout
    log4perl.appender.Logfile.layout.ConversionPattern = \\
        [%d] %p - script: %F - line number: %L - message: %m%n
);

Log::Log4perl::init(\$conf);
my $logger = Log::Log4perl->get_logger('jjp::net');

# ------------------------------------------------------------------------------
# -- globals -------------------------------------------------------------------
# ------------------------------------------------------------------------------
my $connection_dir = '/etc/NetworkManager/system-connections';
my $netfile = undef;
my $connection = undef;
my $ssid = '--';
my $psk = '--';
my $status = 'none';
my $ip = '--';
my $gateway = '--';
my $mask = '--';
my $dns_1 = '--';
my $dns_2 = '--';

# ------------------------------------------------------------------------------
# -- main ----------------------------------------------------------------------
# ------------------------------------------------------------------------------
my @output = `nmcli -c no --get-values NAME,TYPE con show --active`;
foreach (@output) {
    chomp;
    if (/wireless/) {
        my @fields = split /:/, $_;
        $connection = $fields[0];
        $connection =~ s/\.nmconnection//;
    }
}

# older versions of NetworkManager don't append .nmconnection to the filename
if (defined $connection) {
    if (-f "$connection_dir/$connection.nmconnection") {
        $netfile = "$connection_dir/$connection.nmconnection";
    } elsif (-f "$connection_dir/$connection") {
        $netfile = "$connection_dir/$connection";
    }
}

if (defined $connection and defined $netfile) {
    $psk = `grep 'psk=' "$netfile" 2> /dev/null`;
    if (defined $psk and $psk ne '') {
        chomp $psk;
        $psk =~ s/psk=//;
    } else {
        $psk = '--';
    }

    my $status = `nmcli networking connectivity`;
    if (defined $status and $status ne '') {
        chomp $status;
    } else {
        $status = 'none'
    }

    my @lines = `nmcli -c no con show '$connection'`;
    foreach (@lines) {
        chomp;
        if (/IP4\.ADDRESS/) {
            s/.*: *//;
            s/\/.*//;
            if (defined $_ and $_ ne '') {
                $ip = $_;
            }
        } elsif (/802-11-wireless\.ssid:/) {
            s/802-11-wireless\.ssid: *//;
            if (defined $_ and $_ ne '') {
                $ssid = $_;
            }
        } elsif (/IP4\.GATEWAY:/) {
            s/IP4\.GATEWAY: *//;
            if (defined $_ and $_ ne '') {
                $gateway = $_;
            }
        } elsif (/.* subnet_mask = /) {
            s/.* subnet_mask = //;
            if (defined $_ and $_ ne '') {
                $mask = $_;
            }
        } elsif (/IP4\.DNS\[1\]:/) {
            s/IP4\.DNS\[1\]: *//;
            if (defined $_ and $_ ne '') {
                $dns_1 = $_;
            }
        } elsif (/IP4\.DNS\[2\]:/) {
            s/IP4\.DNS\[2\]: *//;
            if (defined $_ and $_ ne '') {
                $dns_2 = $_;
            }
        }
    }

    if ($ssid ne '--') {
        $connection = $ssid;
    }

	print "$connection:$psk:$status:$ip:$gateway:$mask:$dns_1:$dns_2:";
} else {
    print '--:********:none:--:--:--:--:--:';
}
