#!/usr/bin/perl
# ------------------------------------------------------------------------------
# -- Copyright (c) 2021 Jersey Jack Pinball ------------------------------------
# ------------------------------------------------------------------------------
use utf8;
use strict;
use warnings;
use Log::Log4perl;
use JSON;

# ------------------------------------------------------------------------------
# -- libraries -----------------------------------------------------------------
# ------------------------------------------------------------------------------
require '/jjpe/gen1/scripts/net/sb.pm';

# ------------------------------------------------------------------------------
# -- constants -----------------------------------------------------------------
# ------------------------------------------------------------------------------
use constant SB_SYNC_NO_ACHS => '-5';
use constant SB_SYNC_BAD_ID => '-10';

# ------------------------------------------------------------------------------
# -- logging -------------------------------------------------------------------
# ------------------------------------------------------------------------------
my $conf = q(
    log4perl.category.jjp.net          = INFO, Logfile
    log4perl.appender.Logfile          = Log::Log4perl::Appender::File
    log4perl.appender.Logfile.filename = /jjpe/temp/net.log
    log4perl.appender.Logfile.layout   = Log::Log4perl::Layout::PatternLayout
    log4perl.appender.Logfile.layout.ConversionPattern = \\
        [%d] %p - script: %F - line number: %L - message: %m%n
);

Log::Log4perl::init(\$conf);
my $logger = Log::Log4perl->get_logger('jjp::net');

# ------------------------------------------------------------------------------
# -- functions -----------------------------------------------------------------
# ------------------------------------------------------------------------------
sub print_achievements {
    my ($achs) = @_;
    foreach (@$achs) {
        my $achieved = $_->{'achieved'};
        my $count = $_->{'count'} + 0;
        my @fields = split /-/, $_->{'key'};
        print "$fields[2]:$fields[3]:$achieved:$count:\n";
    }
}

# ------------------------------------------------------------------------------
# -- main ----------------------------------------------------------------------
# ------------------------------------------------------------------------------
my ($stoken, $machine_id, $user_id) = @ARGV;
if (not defined $stoken or not defined $machine_id or not defined $user_id) {
    $logger->error('missing args');
    exit;
}

my $server = sb::get_scorbit_server();
my $caching = sb::get_cache_header();
my $command = "curl -s -H 'Authorization: SToken $stoken' $caching "
    ."$server/user_achievement/$machine_id?users=$user_id 2> /dev/null";
my $reply = `$command`;
my $decoded_reply = decode_json($reply);
if ($decoded_reply) {
    if (ref $decoded_reply eq 'ARRAY') {
		if (scalar(@{@$decoded_reply[0]->{'achievements'}})) {
            print_achievements @$decoded_reply[0]->{'achievements'};
        } else {
            my $no_achs_reply = SB_SYNC_NO_ACHS.":0:0:0:\n";
            print $no_achs_reply;
            $logger->error($reply);
        }
    } else {
        my $error_reply = SB_SYNC_BAD_ID.":0:0:0:\n";
        print $error_reply;
        $logger->error($reply);
    }
}
