#!/usr/bin/perl
# ------------------------------------------------------------------------------
# -- Copyright (c) 2021 Jersey Jack Pinball ------------------------------------
# ------------------------------------------------------------------------------
use utf8;
use strict;
use warnings;
use File::Copy;
use Log::Log4perl;
use JSON;

# ------------------------------------------------------------------------------
# -- libraries -----------------------------------------------------------------
# ------------------------------------------------------------------------------
require '/jjpe/gen1/scripts/net/sb.pm';

# ------------------------------------------------------------------------------
# -- logging -------------------------------------------------------------------
# ------------------------------------------------------------------------------
my $conf = q(
    log4perl.category.jjp.net          = INFO, Logfile
    log4perl.appender.Logfile          = Log::Log4perl::Appender::File
    log4perl.appender.Logfile.filename = /jjpe/temp/net.log
    log4perl.appender.Logfile.layout   = Log::Log4perl::Layout::PatternLayout
    log4perl.appender.Logfile.layout.ConversionPattern = \\
        [%d] %p - script: %F - line number: %L - message: %m%n
);

Log::Log4perl::init(\$conf);
my $logger = Log::Log4perl->get_logger('jjp::net');

# ------------------------------------------------------------------------------
# -- functions -----------------------------------------------------------------
# ------------------------------------------------------------------------------
sub print_key_result {
    my ($achs, $key, $user_id, $send_id) = @_;
    my $result = 'failure';
    foreach (@$achs) {
        if ($_->{'key'} eq $key) {
            $result = 'success';
            last;
        }
    }

    my @fields = split /-/, $key;
    print "$fields[2]:$fields[3]:$user_id:$send_id:$result:\n";
}

# ------------------------------------------------------------------------------
# -- main ----------------------------------------------------------------------
# ------------------------------------------------------------------------------
my ($stoken, $keys, $user_id, $send_id) = @ARGV;
if (not defined $stoken or not defined $keys or not defined $user_id
	or not defined $send_id) {
    $logger->error('missing args');
    exit;
}

my @achs = ();
my @lines = split /:/, $keys;
foreach (@lines) {
    my @fields = split /,/, $_;
    my %ach;
    $ach{'key'} = $fields[0];
    $ach{'count'} = $fields[1] + 0;
    push @achs, \%ach;
}

$user_id = $user_id + 0;
my $json = JSON->new;
my $data_to_json = {achievements=>\@achs,user_id=>$user_id};
my $json_data = $json->encode($data_to_json);
if (defined $json_data) {
    my $caching = sb::get_cache_header();
    my $command = "curl -s -H 'Authorization: SToken $stoken' $caching "
        ."-H 'Content-Type: application/json' "
        ."--request POST --data '${json_data}' ";
    my $server = sb::get_scorbit_server();
    $command .= "$server/achievement/unlock 2> /dev/null";
	$logger->info($command);
    my $reply = `$command`;
    my $decoded_reply = decode_json($reply);
    if (defined $decoded_reply) {
        if (ref $decoded_reply eq 'ARRAY') {
            if (scalar(@{$decoded_reply})) {
                foreach (@$decoded_reply) {
                    print_key_result \@achs, $_->{'achievement'}{'key'},
                        $user_id, $send_id;
                }
            } else {
                print "-10:0:0:0:failure:\n";
            }
        } else {
            $logger->error($reply);
        }
    }
}
