#!/usr/bin/perl
# ------------------------------------------------------------------------------
# -- Copyright (c) 2021 Jersey Jack Pinball ------------------------------------
# ------------------------------------------------------------------------------
use utf8;
use strict;
use warnings;
use File::Copy;
use Log::Log4perl;
use JSON;

# ------------------------------------------------------------------------------
# -- libraries -----------------------------------------------------------------
# ------------------------------------------------------------------------------
require '/jjpe/gen1/scripts/net/sb.pm';

# ------------------------------------------------------------------------------
# -- constants -----------------------------------------------------------------
# ------------------------------------------------------------------------------
use constant SB_NULL_DISPLAY_NAME => 'null';
use constant SB_NULL_INITIALS => '!!!';
my $ERROR_REPLY = SB_NULL_DISPLAY_NAME.":0:\n".SB_NULL_DISPLAY_NAME.":0:\n".
	SB_NULL_DISPLAY_NAME.":0:\n".SB_NULL_DISPLAY_NAME.":0:\n";

# ------------------------------------------------------------------------------
# -- logging -------------------------------------------------------------------
# ------------------------------------------------------------------------------
my $conf = q(
    log4perl.category.jjp.net          = INFO, Logfile
    log4perl.appender.Logfile          = Log::Log4perl::Appender::File
    log4perl.appender.Logfile.filename = /jjpe/temp/net.log
    log4perl.appender.Logfile.layout   = Log::Log4perl::Layout::PatternLayout
    log4perl.appender.Logfile.layout.ConversionPattern = \\
        [%d] %p - script: %F - line number: %L - message: %m%n
);

Log::Log4perl::init(\$conf);
my $logger = Log::Log4perl->get_logger('jjp::net');

# ------------------------------------------------------------------------------
# -- functions -----------------------------------------------------------------
# ------------------------------------------------------------------------------
sub print_player {
    my ($players, $position) = @_;
    my $id = '0';
    my $name = SB_NULL_DISPLAY_NAME;
	my $initials = SB_NULL_INITIALS;
    foreach (@{$players}) {
        if ($_->{'position'} == $position) {
            $id = $_->{'id'};
            $name = $_->{'name'};
			$initials = $_->{'initials'};
            last;
        }
    }

    print "$name:$id:$initials:\n";
}

# ------------------------------------------------------------------------------
# -- main ----------------------------------------------------------------------
# ------------------------------------------------------------------------------
my ($stoken, $uuid, $sequence, $time, $active, $player_up, $cur_ball, $s1, $s2,
    $s3, $s4, $game_modes) = @ARGV;
if (not defined $stoken or not defined $uuid or not defined $sequence
    or not defined $time or not defined $active or not defined $player_up
    or not defined $cur_ball or not defined $s1 or not defined $s2
    or not defined $s3 or not defined $s4) {
    $logger->error('missing args');
    exit;
}

if (not defined $game_modes) {
    $game_modes = '';
}

mkdir '/jjpe/temp/sb', 0755;
if (open SBLOG, '>>', "/jjpe/temp/sb/$uuid.csv") {
    my $sbs2 = $s2; my $sbs3 = $s3; my $sbs4 = $s4;
    if ($sbs2 eq '-1') { $sbs2 = ''; }
    if ($sbs3 eq '-1') { $sbs3 = ''; }
    if ($sbs4 eq '-1') { $sbs4 = ''; }
    if (defined $game_modes and $game_modes ne '') {
        $game_modes = "\"$game_modes\"";
    }

    my $epoch = time();
    printf SBLOG ("%u,%s,%s,%s,%s,,,%s,%s,%s\n", $epoch, $s1, $sbs2, $sbs3,
        $sbs4, $player_up, $cur_ball, $game_modes);
    close SBLOG;

    if ($active eq 'false') {
        mkdir '/jjpe/temp/sb/send', 0755;
        move "/jjpe/temp/sb/$uuid.csv", "/jjpe/temp/sb/send/$uuid.csv";
        system "/jjpe/gen1/scripts/net/sbsendcsv.pl $stoken $uuid &";
    }
 
    my $caching = sb::get_cache_header();
    my $command = "curl -s -H 'Authorization: SToken $stoken' $caching "
        ."-d session_uuid=$uuid -d session_sequence=$sequence "
        ."-d session_time=$time -d active=$active -d current_p1_score=$s1 "
        ."-d current_p2_score=$s2 -d current_p3_score=$s3 "
        ."-d current_p4_score=$s4 -d current_player=$player_up "
        ."-d current_ball=$cur_ball ";
    if (defined $game_modes and $game_modes ne '') {
        $command .= "-d game_modes=$game_modes ";
    }

    my $server = sb::get_scorbit_server();
    $command .= "$server/entry/ 2> /dev/null";
    my $reply = `$command`;
	$logger->info($reply);
    my $decoded_reply = decode_json($reply);
    if (defined $decoded_reply->{'scores'}) {
        my @players = ();
        foreach (@{$decoded_reply->{'scores'}}) {
            my %player;
            $player{'id'} = 0;
            $player{'name'} = SB_NULL_DISPLAY_NAME;
            $player{'initials'} = SB_NULL_INITIALS;
            $player{'position'} = $_->{'position'};
            if (defined $_->{'player'}) {
                my $id = $_->{'player'}{'id'};
                my $name = $_->{'player'}{'cached_display_name'};
                if (defined $id and defined $name) {
                    $player{'id'} = $id;
                    $player{'name'} = $name;
                    if (defined $_->{'player'}{'initials'} and
                        $_->{'player'}{'initials'}) {
                        $player{'initials'} = $_->{'player'}{'initials'};
                    }
                }
            }

            push @players, \%player;
        }

        print_player \@players, 1;
        print_player \@players, 2;
        print_player \@players, 3;
        print_player \@players, 4;
    } else {
        print $ERROR_REPLY;
    }
} else {
    $logger->error('could not open csv file');
    print $ERROR_REPLY;
}
