#!/usr/bin/perl
# ------------------------------------------------------------------------------
# -- Copyright (c) 2021 Jersey Jack Pinball ------------------------------------
# ------------------------------------------------------------------------------
use utf8;
use strict;
use warnings;
use Log::Log4perl;

# ------------------------------------------------------------------------------
# -- logging -------------------------------------------------------------------
# ------------------------------------------------------------------------------
my $conf = q(
    log4perl.category.jjp.net          = INFO, Logfile
    log4perl.appender.Logfile          = Log::Log4perl::Appender::File
    log4perl.appender.Logfile.filename = /jjpe/temp/net.log
    log4perl.appender.Logfile.layout   = Log::Log4perl::Layout::PatternLayout
    log4perl.appender.Logfile.layout.ConversionPattern = \\
        [%d] %p - script: %F - line number: %L - message: %m%n
);

Log::Log4perl::init(\$conf);
my $logger = Log::Log4perl->get_logger('jjp::net');

# ------------------------------------------------------------------------------
# -- main ----------------------------------------------------------------------
# ------------------------------------------------------------------------------
my ($update_filename) = @ARGV;
if (not defined $update_filename) {
    $logger->error('missing args');
    exit;
}

chdir '/jjpe/temp';
if (-e $update_filename) {
    $logger->info("unzipping file $update_filename");
    system "unzip -qq $update_filename 2> /dev/null";
    my $ret_code = ($? >> 8);
    if ($ret_code == 0) {
        $logger->info("unzipped file $update_filename");
        system "sync";
        print 'success';
    } else {
        $logger->error("could not unzip $update_filename: $ret_code");
        print 'failure';
    }
} else {
    $logger->error("could not find file $update_filename to unzip");
    print 'failure';
}
